######################################################################
#
# File: test/unit/v1/apiver/apiver_deps.py
#
# Copyright 2020 Backblaze Inc. All Rights Reserved.
#
# License https://www.backblaze.com/using_b2_code.html
#
######################################################################

from b2sdk.v1 import *  # noqa

V = 1
